# -*- coding: utf-8 -*-
from collections import Iterable
from libc.stdlib cimport malloc, free

cdef extern from "_jenks.c":
    void *JenksBreakValues(double *values, unsigned int nb_class,
                           unsigned int length_array, double *breaks)

cpdef _jenks_breaks(values, nb_class):
    cdef:
        list breaks = []
        unsigned int _n_breaks = int(nb_class) + 1
        unsigned int len_values = len(values), i = 0
        double *_values = <double *>malloc(<unsigned int>len_values * sizeof(double))
        double *_breaks = <double *>malloc(<unsigned int>_n_breaks * sizeof(double))

    for i in range(len_values):
        _values[i] = <double>values[i]

    JenksBreakValues(_values, <unsigned int>_n_breaks - 1, len_values, _breaks)

    for i in range(<unsigned int>_n_breaks):
        breaks.append(_breaks[i])

    free(_values)
    free(_breaks)

    return breaks


# -*- coding: utf-8 -*-
import setuptools
from distutils.core import setup
from distutils.extension import Extension
from ast import parse
from os import path
try:
    from future_builtins import filter
except ImportError:
    pass

try:
    from Cython.Distutils import build_ext
    from Cython.Build import cythonize
    USE_CYTHON = True
except:
    USE_CYTHON = False

ext = '.pyx' if USE_CYTHON else '.c'

exts = [Extension("jenkspy.jenks",
        ["jenkspy/src/jenks" + ext], ["jenkspy"])]

with open(path.join('jenkspy', '__init__.py')) as f:
    __version__ = parse(next(filter(lambda line: line.startswith('__version__'),
                                     f))).body[0].value.s

setup(
    name='jenkspy',
    version=__version__,
    license="MIT",
    ext_modules=cythonize(exts) if USE_CYTHON else exts,
    cmdclass={'build_ext': build_ext} if USE_CYTHON else {},
    packages=["jenkspy"],
    include_package_data=True,
    description="Compute Natural Breaks (Jenks algorythm)",
    test_suite="tests",
    author="mthh",
    author_email="matthieu.viry@ums-riate.fr",
    url='http://github.com/mthh/jenkspy',
    classifiers=[
        "Programming Language :: Python",
        "Development Status :: 4 - Beta",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Topic :: Scientific/Engineering",
        ],
    )
